Package: hockeystick
Title: Download and Visualize Essential Global Heating Data
Version: 1.0.0
Authors@R: 
    person(given = "Hernando",
           family = "Cortina",
           role = c("aut", "cre"),
           email = "hch@alum.mit.edu",
           comment = c(ORCID = "0000-0001-6790-4870"))
Description: Provides easy access to essential climate change datasets to non-climate experts. Users can download the latest raw data from authoritative sources and view it via pre-defined 'ggplot2' charts. Datasets include atmospheric CO2, methane, emissions, instrumental and proxy temperature records, CMIP6 projections, sea levels, Arctic/Antarctic sea-ice, Hurricanes, Wildfires, and Paleoclimate data. Sources include: NOAA Mauna Loa Laboratory <https://gml.noaa.gov/ccgg/trends/data.html>, Global Carbon Project <https://www.globalcarbonproject.org/carbonbudget/>, NASA GISTEMP <https://data.giss.nasa.gov/gistemp/>, National Snow and Sea Ice Data Center <https://nsidc.org/home>, CSIRO <https://research.csiro.au/slrwavescoast/sea-level/measurements-and-data/sea-level-data/>, NOAA Laboratory for Satellite Altimetry <https://www.star.nesdis.noaa.gov/socd/lsa/SeaLevelRise/> and HURDAT Atlantic Hurricane Database <https://www.aoml.noaa.gov/hrd/hurdat/Data_Storm.html>, Vostok Paleo carbon dioxide and temperature data: <doi:10.3334/CDIAC/ATG.009>.
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://cortinah.github.io/hockeystick/,
        https://github.com/cortinah/hockeystick
BugReports: https://github.com/cortinah/hockeystick/issues
Imports: ggplot2, lubridate, tools, readr, dplyr, tidyr, patchwork,
        scales, rvest, tibble, treemapify, RColorBrewer, jsonlite,
        readxl
Depends: R (>= 4.1.0)
Suggests: rmarkdown, knitr, spelling, viridisLite, quarto, terra,
        geodata, svglite, testthat (>= 3.0.0)
Config/testthat/edition: 3
Language: en-US
VignetteBuilder: quarto
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-26 23:56:14 UTC; hernandocortina
Author: Hernando Cortina [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6790-4870>)
Maintainer: Hernando Cortina <hch@alum.mit.edu>
Repository: CRAN
Date/Publication: 2026-08-28 09:50:16 UTC
