# Generated by roxygen2: do not edit by hand

S3method(print,hockeystick_cache_info)
export(climate_grid)
export(emissions_map)
export(get_carbon)
export(get_dailytemp)
export(get_dailytempcop)
export(get_emissions)
export(get_hurricanes)
export(get_icecurves)
export(get_methane)
export(get_paleo)
export(get_seaice)
export(get_sealevel)
export(get_temp)
export(get_temp2k)
export(hockeystick_cache_delete)
export(hockeystick_cache_delete_all)
export(hockeystick_cache_details)
export(hockeystick_cache_list)
export(hockeystick_update_all)
export(merge_carbontemp)
export(plot_carbon)
export(plot_carbontemp)
export(plot_dailytemp)
export(plot_emissions)
export(plot_emissions_with_land)
export(plot_hurricane_nrg)
export(plot_hurricanes)
export(plot_icecurves)
export(plot_methane)
export(plot_paleo)
export(plot_seaice)
export(plot_sealevel)
export(plot_temp)
export(plot_temp2k)
export(plot_temp_monthly)
export(plot_temp_scatter)
export(warming_stripes)
import(dplyr)
import(ggplot2)
import(lubridate)
import(patchwork)
import(rvest)
import(tidyr)
import(treemapify)
importFrom(RColorBrewer,brewer.pal)
importFrom(dplyr,filter)
importFrom(dplyr,full_join)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,summarize_all)
importFrom(ggplot2,ggplot)
importFrom(jsonlite,fromJSON)
importFrom(lubridate,ceiling_date)
importFrom(lubridate,date_decimal)
importFrom(lubridate,days)
importFrom(lubridate,month)
importFrom(lubridate,round_date)
importFrom(lubridate,year)
importFrom(lubridate,ym)
importFrom(lubridate,ymd)
importFrom(patchwork,wrap_plots)
importFrom(readr,col_skip)
importFrom(readr,cols)
importFrom(readr,parse_number)
importFrom(readr,read_csv)
importFrom(readr,read_table)
importFrom(readxl,read_xlsx)
importFrom(scales,unit_format)
importFrom(stats,na.omit)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_longer)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,tail)
importFrom(utils,unzip)
