# This file is part of the R package "hockeystick".
# It is made available under the terms of the GNU General Public
# License, version 2 (GPL-2), or (at your option) any later version.

library(testthat)
library(hockeystick)

test_check("hockeystick")
