# Setting global variables to avoid R CMD check notices
utils::globalVariables(c('average', 'trend', 'year','Year', 'J-D', 'gmsl', 'method', 'month', 'name',
                         'age_ice', 'co2', 'land_use_change_co2', 'temp', 'value', 'size', 'measure','RevisedMajorHurricanes', 'RevisedACE',
                         'cumco2', 'country', 'data1', 'data366', 'day_of_year', 'dummy_date', 'linew', 'mean_temp', 'temp_anom',
                         'hurr_type', 'ice_region', 'data_source', 'Anomaly', 'Month', 'Date', 'Carbon','1991-2020 mean',
                         'area_ha', 'area_ha_avg', 'area_ha_max', 'area_ha_min', 'avgv', 'cum_area_ha',
                         'cum_area_ha_avg', 'cum_area_ha_max', 'cum_area_ha_min', 'cum_avgv', 'cum_curv',
                         'cum_events', 'cum_events_avg', 'cum_events_max', 'cum_events_min', 'cum_maxv',
                         'cum_minv curv', 'dt', 'events', 'events_avg', 'events_max', 'events_min', 'fires', 'maxv',
                         'mddate', 'minv', 'plt', 'cum_minv', 'curv' ))
