% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_cache.R
\name{file_info_}
\alias{file_info_}
\title{Display cached file info}
\usage{
file_info_(x)
}
\arguments{
\item{x}{filenames}
}
\description{
Internal function
}
