% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_cache.R
\name{getsize}
\alias{getsize}
\title{Get rounded size of file in kB}
\usage{
getsize(x)
}
\arguments{
\item{x}{filenames}
}
\description{
Internal function
}
