% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_cache.R
\name{hscache_path}
\alias{hscache_path}
\title{Return path of data cache directory}
\usage{
hscache_path()
}
\value{
Return path of data cache directory
}
\description{
Internal Function
}
